<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_BE">
<context>
    <name>BlackoutWidget</name>
    <message>
        <source>Click to Return to Application</source>
        <translation>Klik om terug te keren naar de toepassing</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Clean Up</source>
        <translation>Opruimen</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 items</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation>Formulier</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Bestandsnaam</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Probeer opnieuw</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
</context>
<context>
    <name>IntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast via YouTube publiceren</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Board</source>
        <translation>Bord</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Documenten</translation>
    </message>
    <message>
        <source>Stylus</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>Achtergronden</translation>
    </message>
    <message>
        <source>Change Background</source>
        <translation>Achtergrond wijzigen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Herhalen</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Vorige Pagina</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>Naar boven</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Volgende pagina</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>Naar beneden</translation>
    </message>
    <message>
        <source>Manage Documents</source>
        <translation>Document beheren</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Web Browsing</source>
        <translation>Web surfen</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Small Line</source>
        <translation>Dunne lijn</translation>
    </message>
    <message>
        <source>Medium Line</source>
        <translation>Medium lijn</translation>
    </message>
    <message>
        <source>Large Line</source>
        <translation>Dikke lijn</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Verlaten</translation>
    </message>
    <message>
        <source>Eraser</source>
        <translation>Wisser</translation>
    </message>
    <message>
        <source>Smalle Eraser</source>
        <translation type="vanished">Kleine wisser</translation>
    </message>
    <message>
        <source>Medium Eraser</source>
        <translation>Middelgrote wisser</translation>
    </message>
    <message>
        <source>Large Eraser</source>
        <translation>Brede wisser</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Kleur</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vooruit</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Opnieuw laden</translation>
    </message>
    <message>
        <source>Reload Current Page</source>
        <translation>Huidige pagina opnieuw laden</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Load Home Page</source>
        <translation>Homepage laden</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favorieten</translation>
    </message>
    <message>
        <source>Show Bookmarks</source>
        <translation>Favorieten weergeven</translation>
    </message>
    <message>
        <source>Bookmark</source>
        <translation>Favoriet</translation>
    </message>
    <message>
        <source>Add Bookmark</source>
        <translation>Favoriet toevoegen</translation>
    </message>
    <message>
        <source>Display Board</source>
        <translation>Bord weergeven</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>Erase</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Erase Content</source>
        <translation>Inhoud wissen</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <source>Display Preferences</source>
        <translation>Voorkeuren weergeven</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotheek</translation>
    </message>
    <message>
        <source>Show Library</source>
        <translation>Bibliotheek weergeven</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>Show Desktop</source>
        <translation>Bureaublad weergeven</translation>
    </message>
    <message>
        <source>Show Computer Desktop</source>
        <translation>Computer desktop weergeven</translation>
    </message>
    <message>
        <source>Ctrl+Shift+H</source>
        <translation>Ctrl+Shift+H</translation>
    </message>
    <message>
        <source>Bigger</source>
        <translation>Vergroten</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Smaller</source>
        <translation>Verkleinen</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nieuwe map</translation>
    </message>
    <message>
        <source>Create a New Folder</source>
        <translation>Nieuwe map aanmaken</translation>
    </message>
    <message>
        <source>New Document</source>
        <translation>Nieuw document</translation>
    </message>
    <message>
        <source>Create a New Document</source>
        <translation>Nieuw document maken</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importeren</translation>
    </message>
    <message>
        <source>Import a Document</source>
        <translation>Een document importeren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporteren</translation>
    </message>
    <message>
        <source>Export a Document</source>
        <translation>Een document exporteren</translation>
    </message>
    <message>
        <source>Open in Board</source>
        <translation>In bord openen</translation>
    </message>
    <message>
        <source>Open Page in Board</source>
        <translation>Pagina in bord openen</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliceren</translation>
    </message>
    <message>
        <source>Duplicate Selected Content</source>
        <translation>De geselecteerde inhoud dupliceren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Delete Selected Content</source>
        <translation>De geselecteerde inhoud verwijderen</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Add to Working Document</source>
        <translation>Aan werkdocument toevoegen</translation>
    </message>
    <message>
        <source>Add Selected Content to Open Document</source>
        <translation>De geselecteerde tekst aan het Open Document toevoegen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Add Content to Document</source>
        <translation>Inhoud aan document toevoegen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Rename Content</source>
        <translation>Tekst naam wijzigen</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Tools</translation>
    </message>
    <message>
        <source>Display Tools</source>
        <translation>Tools weergeven</translation>
    </message>
    <message>
        <source>Multi Screen</source>
        <translation>Multi Scherm</translation>
    </message>
    <message>
        <source>Wide Size (16/9)</source>
        <translation>Brede schermafmeting(16/9)</translation>
    </message>
    <message>
        <source>Use Document Wide Size (16/9)</source>
        <translation>Document breedschermafmeting gebruiken(16/9)</translation>
    </message>
    <message>
        <source>Regular Size (4/3)</source>
        <translation>Standaard schermafmeting(4/3)</translation>
    </message>
    <message>
        <source>Use Document Regular Size (4/3)</source>
        <translation>Document op standaard schermafmeting gebruiken(4/3)</translation>
    </message>
    <message>
        <source>Custom Size</source>
        <translation>Aangepaste afmetingen</translation>
    </message>
    <message>
        <source>Use Custom Document Size</source>
        <translation>Gebruik aangepaste Documentafmeting</translation>
    </message>
    <message>
        <source>Stop Loading</source>
        <translation>Stop laden</translation>
    </message>
    <message>
        <source>Stop Loading Web Page</source>
        <translation>Stop laden van de webpagina</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Knippen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Plakken</translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Put Presentation to Sleep</source>
        <translation>De presentatie in de slaapstand zetten</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtuele toetsenboord</translation>
    </message>
    <message>
        <source>Display Virtual Keyboard</source>
        <translation>Virtuele toetsenboord weergeven</translation>
    </message>
    <message>
        <source>Plain Light Background</source>
        <translation>Lichte neutrale achtergrond</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>licht</translation>
    </message>
    <message>
        <source>Grid Light Background</source>
        <translation>Licht rooster achtergrond</translation>
    </message>
    <message>
        <source>Plain Dark Background</source>
        <translation>Neutraal donkere achtergrond</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Donker</translation>
    </message>
    <message>
        <source>Grid Dark Background</source>
        <translation>Donker rooster achtergrond</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Record Presentation to Video</source>
        <translation>Neem Presentatie op als Video</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Opnemen</translation>
    </message>
    <message>
        <source>Start Screen Recording</source>
        <translation>Een schermopname starten</translation>
    </message>
    <message>
        <source>Erase Items</source>
        <translation>Items wissen</translation>
    </message>
    <message>
        <source>Erase All Items</source>
        <translation>Alle items wissen</translation>
    </message>
    <message>
        <source>Erase Annotations</source>
        <translation>Aantekeningen wissen</translation>
    </message>
    <message>
        <source>Erase All Annotations</source>
        <translation>Alle aantekeningen wissen</translation>
    </message>
    <message>
        <source>Clear Page</source>
        <translation>Pagina wissen</translation>
    </message>
    <message>
        <source>Clear All Elements</source>
        <translation>Alle onderdelen wissen</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Annotate Document</source>
        <translation>Aantekening op document toevoegen</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Erase Annotation</source>
        <translation>Aantekening wissen</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markeerstift</translation>
    </message>
    <message>
        <source>Highlight </source>
        <translation>Markeren</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>Selector</source>
        <translation>Keuzeschakelaar</translation>
    </message>
    <message>
        <source>Select And Modify Objects</source>
        <translation>Objecten selecteren en wijzigingen</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Hand</source>
        <translation>Hand</translation>
    </message>
    <message>
        <source>Scroll Page</source>
        <translation>Pagina scrollen</translation>
    </message>
    <message>
        <source>Laser Pointer</source>
        <translation>Laserpointer</translation>
    </message>
    <message>
        <source>Virtual Laser Pointer</source>
        <translation>Virtuele laserpointer</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Draw Lines</source>
        <translation>Lijnen tekenen</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>CTRL+J</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Write Text</source>
        <translation>Tekst schrijven</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Capture</source>
        <translation>Opname</translation>
    </message>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Deel van scherm opnemen</translation>
    </message>
    <message>
        <source>Add To Current Page</source>
        <translation>Aan huidige pagina toevoegen</translation>
    </message>
    <message>
        <source>Add Item To Current Page</source>
        <translation>Item aan huidige pagina toevoegen</translation>
    </message>
    <message>
        <source>Add To New Page</source>
        <translation>Aan nieuwe pagina toevoegen</translation>
    </message>
    <message>
        <source>Add Item To New Page</source>
        <translation>Item aan nieuwe pagina toevoegen</translation>
    </message>
    <message>
        <source>Add To Library</source>
        <translation>Aan bibliotheek toevoegen</translation>
    </message>
    <message>
        <source>Add Item To Library</source>
        <translation>Item aan bibliotheek toevoegen</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Pagina&apos;s</translation>
    </message>
    <message>
        <source>Create a New Page</source>
        <translation>Een nieuwe pagina maken</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Nieuwe pagina</translation>
    </message>
    <message>
        <source>Duplicate Page</source>
        <translation>Pagina Dupliceren</translation>
    </message>
    <message>
        <source>Duplicate the Current Page</source>
        <translation>Huidige pagina Dupliceren</translation>
    </message>
    <message>
        <source>Import Page</source>
        <translation>Pagina importeren</translation>
    </message>
    <message>
        <source>Import an External Page</source>
        <translation>Een externe pagina importeren</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauze</translation>
    </message>
    <message>
        <source>Pause Podcast Recording</source>
        <translation>Pauze Podcast opname</translation>
    </message>
    <message>
        <source>Podcast Config</source>
        <translation>Podcast configuratie</translation>
    </message>
    <message>
        <source>Configure Podcast Recording</source>
        <translation>Podcast opname configureren</translation>
    </message>
    <message>
        <source>Flash Trap</source>
        <translation type="vanished">Flash Trap</translation>
    </message>
    <message>
        <source>Trap Flash Content</source>
        <translation type="vanished">Trap flash inhoud</translation>
    </message>
    <message>
        <source>Web Trap</source>
        <translation>Internet bescherming</translation>
    </message>
    <message>
        <source>Trap Web Content</source>
        <translation>Webinhoud bescherming</translation>
    </message>
    <message>
        <source>Custom Capture</source>
        <translation>Opname instellen</translation>
    </message>
    <message>
        <source>Window Capture</source>
        <translation>Vensteropname</translation>
    </message>
    <message>
        <source>Capture a Window</source>
        <translation>Venster opnemen</translation>
    </message>
    <message>
        <source>Embed Web Content</source>
        <translation>Internetinhoud insluiten</translation>
    </message>
    <message>
        <source>Capture Embeddable Web Content</source>
        <translation>Opnemen insluitbare webinhoud</translation>
    </message>
    <message>
        <source>Show on Display</source>
        <translation>Op presentatiescherm weergeven</translation>
    </message>
    <message>
        <source>Show Main Screen on Display Screen</source>
        <translation>Het hoofdscherm op presentatiescherm weergeven</translation>
    </message>
    <message>
        <source>Erase all Annotations</source>
        <translation>Alle aantekeningen wissen</translation>
    </message>
    <message>
        <source>eduMedia</source>
        <translation>eduMedia</translation>
    </message>
    <message>
        <source>Import eduMedia simulation</source>
        <translation>eduMedia simulatie importeren</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Update controleren</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">OpenBoard</translation>
    </message>
    <message>
        <source>Quit OpenBoard</source>
        <translation>Verlaat OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard</source>
        <translation>Verberg OpenBoard</translation>
    </message>
    <message>
        <source>Hide OpenBoard Application</source>
        <translation>Verberg OpenBoard Toepassing</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Speel</translation>
    </message>
    <message>
        <source>Interact with items</source>
        <translation>Aan de slag met onderdelen</translation>
    </message>
    <message>
        <source>Erase Background</source>
        <translation>Achtergrond wissen</translation>
    </message>
    <message>
        <source>Remove the backgound</source>
        <translation>Achtyergrond verwijderen</translation>
    </message>
    <message>
        <source>Ruled Light Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ruled Dark Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Tutorial</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open the tutorial web page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small Eraser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color 5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Web Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Iinloggen verplicht</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruiksersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Proxy identificatie</translation>
    </message>
    <message>
        <source>Connect to Proxy</source>
        <translation>Met proxy verbinden</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Save username and password for future use</source>
        <translation>Gebruikersnaam en wachtwoord onthouden</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Remove Page</source>
        <translation type="unfinished">Pagina verwijderen</translation>
    </message>
    <message>
        <source>Element ID = </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Content is not supported in destination format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove 1 page from the selected document &apos;%0&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading scene (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving cached scenes (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplication</name>
    <message>
        <source>Page Size</source>
        <translation>Pagina Formaat</translation>
    </message>
    <message>
        <source>Podcast</source>
        <translation>Podcast</translation>
    </message>
    <message>
        <source>Cannot open your UBX file directly. Please import it in Documents mode instead</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBApplicationController</name>
    <message>
        <source>Web</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>New update available, would you go to the web page ?</source>
        <translation>Nieuwe update beschikbaar, wilt u naar de webpagina?</translation>
    </message>
    <message>
        <source>No update available</source>
        <translation>Geen update beschikbaar</translation>
    </message>
    <message>
        <source>Update available</source>
        <translation>update beschikbaar</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Update</translation>
    </message>
</context>
<context>
    <name>UBBackgroundPalette</name>
    <message>
        <source>Grid size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw intermediate grid lines</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBBoardController</name>
    <message>
        <source>Downloading content %1 failed</source>
        <translation>Downloaden inhoud %1 mislukt</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Downloaden voltooid</translation>
    </message>
    <message>
        <source>Unknown tool type %1</source>
        <translation>Onbekend tool type %1</translation>
    </message>
    <message>
        <source>Unknown content type %1</source>
        <translation>Onbekend inhoud type %1</translation>
    </message>
    <message>
        <source>Add Item</source>
        <translation>Item toevoegen</translation>
    </message>
    <message>
        <source>All Supported (%1)</source>
        <translation>Alle ondersteunden (%1)</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving document...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document has just been saved...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting page %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1 deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add file operation failed: file copying error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished">Kleur</translation>
    </message>
</context>
<context>
    <name>UBBoardPaletteManager</name>
    <message>
        <source>Error Adding Image to Library</source>
        <translation>Error foto aan bibliotheek toevoegen</translation>
    </message>
    <message>
        <source>CapturedImage</source>
        <translation>Gegrepen afbeelding</translation>
    </message>
</context>
<context>
    <name>UBBoardThumbnailsView</name>
    <message>
        <source>Loading page (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBCachePropertiesWidget</name>
    <message>
        <source>Cache Properties</source>
        <translation>Cache Eigenschappen</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Kleur:</translation>
    </message>
    <message>
        <source>Shape:</source>
        <translation>Vorm:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Formaat:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>UBDesktopPalette</name>
    <message>
        <source>Capture Part of the Screen</source>
        <translation>Afdruk deel van scherm</translation>
    </message>
    <message>
        <source>Capture the Screen</source>
        <translation>Scherm afdrukken</translation>
    </message>
    <message>
        <source>Show the stylus palette</source>
        <translation>Pen palet weergeven</translation>
    </message>
    <message>
        <source>Show Board on Secondary Screen</source>
        <translation>Board op bijscherm</translation>
    </message>
    <message>
        <source>Show Desktop on Secondary Screen</source>
        <translation>Desktop op bijscherm weergeven</translation>
    </message>
    <message>
        <source>Show OpenBoard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentController</name>
    <message>
        <source>New Folder</source>
        <translation>Nieuwe map</translation>
    </message>
    <message>
        <source>Page %1</source>
        <translation>Pagina %1</translation>
    </message>
    <message>
        <source>Add Folder of Images</source>
        <translation>Beeldmap toevoegen</translation>
    </message>
    <message>
        <source>Add Images</source>
        <translation>Beelden toevoegen</translation>
    </message>
    <message>
        <source>Add Pages from File</source>
        <translation>Pagina&apos;s van bestand toevoegen</translation>
    </message>
    <message>
        <source>Duplicating Document %1</source>
        <translation>Document %1 dupliceren</translation>
    </message>
    <message>
        <source>Document %1 copied</source>
        <translation>Document %1 gekopieerd</translation>
    </message>
    <message>
        <source>Remove Page</source>
        <translation type="vanished">Pagina verwijderen</translation>
    </message>
    <message>
        <source>Remove Document</source>
        <translation type="vanished">Document verwijderen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the document &apos;%1&apos;?</source>
        <translation type="vanished">Weet u zeker dat u document &quot;%1&quot; wilt verwijderen?</translation>
    </message>
    <message>
        <source>Empty Trash</source>
        <translation type="vanished">Prullenbak legen</translation>
    </message>
    <message>
        <source>Are you sure you want to empty trash?</source>
        <translation type="vanished">Weet u zeker dat u de prullenbak wilt legen?</translation>
    </message>
    <message>
        <source>Emptying trash</source>
        <translation type="vanished">Prullenbak wordt geleegd</translation>
    </message>
    <message>
        <source>Emptied trash</source>
        <translation type="vanished">Prullenbak is leeg</translation>
    </message>
    <message>
        <source>Remove Folder</source>
        <translation type="vanished">Map verwijderen</translation>
    </message>
    <message>
        <source>Are you sure you want to remove the folder &apos;%1&apos; and all its content?</source>
        <translation type="vanished">Weet u zeker dat u de map &quot;%1&quot; met inhoud wilt verwijderen?</translation>
    </message>
    <message>
        <source>No document selected!</source>
        <translation type="vanished">Geen document geselecteerd!</translation>
    </message>
    <message>
        <source>Open Supported File</source>
        <translation>Geopend ondersteund bestand</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>File %1 wordt geïmporteerd...</translation>
    </message>
    <message>
        <source>Failed to import file ... </source>
        <translation>Bestand importeren mislukt...</translation>
    </message>
    <message>
        <source>Import all Images from Folder</source>
        <translation>Alle beelden uit map importeren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Leeg</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <source>Open Document</source>
        <translation>Document openen</translation>
    </message>
    <message>
        <source>Add all Images to Document</source>
        <translation>Alle beelden aan Document toevoegen</translation>
    </message>
    <message>
        <source>All Images (%1)</source>
        <translation>Alle beelden (%1)</translation>
    </message>
    <message>
        <source>Selection does not contain any image files!</source>
        <translation>De selectie bevat geen beeldbestand!</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to remove %n page(s) from the selected document &apos;%1&apos;?</source>
        <translation type="vanished">
            <numerusform>Ben je zeker dat je %n pagina van geselecteerde document &apos;%1&apos; wilt verwijderen?</numerusform>
            <numerusform>Ben je zeker dat je %n pagina(s) van geselecteerde document &apos;%1&apos; wilt verwijderen?</numerusform>
        </translation>
    </message>
    <message>
        <source>Untitled Documents</source>
        <translation type="unfinished">Onbenoemde Documenten</translation>
    </message>
    <message numerus="yes">
        <source>duplicated %1 page</source>
        <comment>duplicated %1 pages</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Folder does not contain any image files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The document &apos;%1&apos; has been generated with a newer version of OpenBoard (%2). By opening it, you may lose some information. Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refreshing Document Thumbnails View (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentManager</name>
    <message>
        <source>images</source>
        <translation>beelden</translation>
    </message>
    <message>
        <source>videos</source>
        <translation>video&apos;s</translation>
    </message>
    <message>
        <source>objects</source>
        <translation>voorwerpen</translation>
    </message>
    <message>
        <source>widgets</source>
        <translation>widgets</translation>
    </message>
    <message>
        <source>All supported files (*.%1)</source>
        <translation>Alle ondersteunde bestanden (*.%1)</translation>
    </message>
    <message>
        <source>File %1 saved</source>
        <translation>Bestand %1 opgeslagen</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation type="unfinished">Import gelukt.</translation>
    </message>
    <message>
        <source>Inserting page %1 of %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import of file %1 successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentNavigator</name>
    <message>
        <source>Page %0</source>
        <translation>Pagina %0</translation>
    </message>
    <message>
        <source>Generating thumbnails for board (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentPublisher</name>
    <message>
        <source>Export failed.</source>
        <translation type="obsolete">Export mislukt.</translation>
    </message>
</context>
<context>
    <name>UBDocumentReplaceDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The name %1 is allready used.
Keeping this name will replace the document.
Providing a new name will create a new document.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeModel</name>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Prullenbak</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pagina gekopieerd</numerusform>
            <numerusform>%1 pagina&apos;s gekopieerd</numerusform>
        </translation>
    </message>
    <message>
        <source>My documents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeView</name>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="unfinished">
            <numerusform>%1 pagina gekopieerd</numerusform>
            <numerusform>%1 pagina&apos;s gekopieerd</numerusform>
        </translation>
    </message>
    <message>
        <source>Remove Item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove the selected item(s) ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="unfinished">Kopie van pagina %1/%2</translation>
    </message>
</context>
<context>
    <name>UBDocumentTreeWidget</name>
    <message>
        <source>%1 (copy)</source>
        <translation type="vanished">%1 (kopie)</translation>
    </message>
    <message>
        <source>Copying page %1/%2</source>
        <translation type="vanished">Kopie van pagina %1/%2</translation>
    </message>
    <message numerus="yes">
        <source>%1 pages copied</source>
        <translation type="vanished">
            <numerusform>%1 pagina gekopieerd</numerusform>
            <numerusform>%1 pagina&apos;s gekopieerd</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UBDownloadWidget</name>
    <message>
        <source>Downloading files</source>
        <translation>Bestanden downloaden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnail</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBDraggableThumbnailView</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBExportAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export gelukt.</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to export to the selected location. You do not have the permissions necessary to save the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export failed: location not writable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warnings during export was appeared</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportCFF</name>
    <message>
        <source>Export to IWB</source>
        <translation>Exporteer naar IWB</translation>
    </message>
    <message>
        <source>Export as IWB File</source>
        <translation>Exporteer als IWB bestand</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export gelukt.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export mislukt.</translation>
    </message>
</context>
<context>
    <name>UBExportDocument</name>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Export as UBZ File</source>
        <translation>Exporteren als UBZ bestand</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export gelukt.</translation>
    </message>
    <message>
        <source>Exporting %1 %2 of %3</source>
        <translation>%1 %2 van %3 geëxporteerd</translation>
    </message>
    <message>
        <source>Export to OpenBoard Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportDocumentSetAdaptor</name>
    <message>
        <source>Exporting document...</source>
        <translation type="unfinished">Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="unfinished">Export gelukt.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation type="unfinished">Export mislukt.</translation>
    </message>
    <message>
        <source>Failed to export...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export as UBX File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export to OpenBoard UBX Format</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBExportFullPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporteren als PDF bestand</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export gelukt.</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporteren naar PDF bestand</translation>
    </message>
</context>
<context>
    <name>UBExportPDF</name>
    <message>
        <source>Export as PDF File</source>
        <translation>Exporteren als PDF bestand</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation type="vanished">Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation type="vanished">Export gelukt.</translation>
    </message>
    <message>
        <source>Exporting page %1 of %2</source>
        <translation>%1 van %2 geëxporteerd</translation>
    </message>
    <message>
        <source>Export to PDF</source>
        <translation>Exporteren naar PDF bestand</translation>
    </message>
</context>
<context>
    <name>UBExportWeb</name>
    <message>
        <source>Page</source>
        <translation>Pagina</translation>
    </message>
    <message>
        <source>Export as Web data</source>
        <translation>Exporteren als Webdata</translation>
    </message>
    <message>
        <source>Exporting document...</source>
        <translation>Document wordt geëxporteerd...</translation>
    </message>
    <message>
        <source>Export successful.</source>
        <translation>Export gelukt.</translation>
    </message>
    <message>
        <source>Export failed.</source>
        <translation>Export mislukt.</translation>
    </message>
    <message>
        <source>Export to Web Browser</source>
        <translation>Exporteren naar Web Browser</translation>
    </message>
</context>
<context>
    <name>UBFeatureProperties</name>
    <message>
        <source>Add to page</source>
        <translation>Aan pagina toevoegen</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="vanished">Als achtergrond gebruiken</translation>
    </message>
    <message>
        <source>Add to library</source>
        <translation>Aan bibliotheek toevoegen</translation>
    </message>
    <message>
        <source>Object informations</source>
        <translation>Object informatie</translation>
    </message>
</context>
<context>
    <name>UBFeaturesActionBar</name>
    <message>
        <source>Add to favorites</source>
        <translation>Aan favorieten toevoegen</translation>
    </message>
    <message>
        <source>Share</source>
        <translation>Delen</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Back to folder</source>
        <translation>Terug naar map</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Uit favorieten verwijderen</translation>
    </message>
    <message>
        <source>Create new folder</source>
        <translation>Nieuwe map maken</translation>
    </message>
    <message>
        <source>Rescan file system</source>
        <translation>Bestand systeem opnieuw scannen</translation>
    </message>
</context>
<context>
    <name>UBFeaturesController</name>
    <message>
        <source>ImportedImage</source>
        <translation>Geïmporteerd beeld</translation>
    </message>
    <message>
        <source>Audios</source>
        <translation type="unfinished">Audio&apos;s</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished">Films</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished">Foto&apos;s</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation type="obsolete">Animaties</translation>
    </message>
    <message>
        <source>Interactivities</source>
        <translation type="unfinished">Interactiviteiten</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished">Toepassingen</translation>
    </message>
    <message>
        <source>Shapes</source>
        <translation type="unfinished">Vormen</translation>
    </message>
    <message>
        <source>Trash</source>
        <translation type="unfinished">Prullenbak</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesNewFolderDialog</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter a new folder name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBFeaturesProgressInfo</name>
    <message>
        <source>Loading </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsGroupContainerItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation type="unfinished">Vergrendeld</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation type="unfinished">Weergeven op Verbreed scherm</translation>
    </message>
</context>
<context>
    <name>UBGraphicsItemDelegate</name>
    <message>
        <source>Locked</source>
        <translation>Vergrendeld</translation>
    </message>
    <message>
        <source>Visible on Extended Screen</source>
        <translation>Weergeven op Verbreed scherm</translation>
    </message>
    <message>
        <source>Go to Content Source</source>
        <translation>Naar inhoudsbron</translation>
    </message>
    <message>
        <source>Set as background</source>
        <translation type="unfinished">Als achtergrond gebruiken</translation>
    </message>
</context>
<context>
    <name>UBGraphicsMediaItem</name>
    <message>
        <source>Media resource couldn&apos;t be resolved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsupported media format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media playback service not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Media error: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItem</name>
    <message>
        <source>&lt;Type Text Here&gt;</source>
        <translation>&lt;Schrijf hier uw tekst&gt;</translation>
    </message>
</context>
<context>
    <name>UBGraphicsTextItemDelegate</name>
    <message>
        <source>Text Color</source>
        <translation>Tekstkleur</translation>
    </message>
    <message>
        <source>Editable</source>
        <translation>Bewerkbaar</translation>
    </message>
</context>
<context>
    <name>UBGraphicsW3CWidgetItem</name>
    <message>
        <source>Web</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItem</name>
    <message>
        <source>Loading ...</source>
        <translation type="unfinished">Wordt geladen...</translation>
    </message>
</context>
<context>
    <name>UBGraphicsWidgetItemDelegate</name>
    <message>
        <source>Frozen</source>
        <translation>Bevroren</translation>
    </message>
    <message>
        <source>Transform as Tool </source>
        <translation>Als tool gebruiken</translation>
    </message>
</context>
<context>
    <name>UBImportCFF</name>
    <message>
        <source>Common File Format (</source>
        <translation>Standaard bestandformaat (</translation>
    </message>
    <message>
        <source>Importing file %1...</source>
        <translation>Importering van bestand %1...</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Importering van bestand %1 is mislukt.</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import gelukt.</translation>
    </message>
    <message>
        <source>Import failed.</source>
        <translation>Import mislukt.</translation>
    </message>
</context>
<context>
    <name>UBImportDocument</name>
    <message>
        <source>Importing file %1...</source>
        <translation>Bestand %1 wordt geïmporteerd...</translation>
    </message>
    <message>
        <source>Import successful.</source>
        <translation>Import gelukt.</translation>
    </message>
    <message>
        <source>Import of file %1 failed.</source>
        <translation>Import van bestand %1 mislukt.</translation>
    </message>
    <message>
        <source>OpenBoard (*.ubz)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportDocumentSetAdaptor</name>
    <message>
        <source>Openboard (set of documents) (*.ubx)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBImportImage</name>
    <message>
        <source>Image Format (</source>
        <translation>Beeldformaat (</translation>
    </message>
</context>
<context>
    <name>UBImportPDF</name>
    <message>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Draagbaar Document Formaat (*.pdf)</translation>
    </message>
    <message>
        <source>PDF import failed.</source>
        <translation>PDF import mislukt.</translation>
    </message>
    <message>
        <source>Importing page %1 of %2</source>
        <translation>Importering van pagina %1 van %2 gelukt</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublisher</name>
    <message>
        <source>Error while publishing video to intranet (%1)</source>
        <translation>Fout opgetreden tijdens video uploading op internet (%1)</translation>
    </message>
    <message>
        <source>Publishing to Intranet in progress %1 %</source>
        <translation>Wordt op Intranet gepubliceerd %1%</translation>
    </message>
</context>
<context>
    <name>UBIntranetPodcastPublishingDialog</name>
    <message>
        <source>Publish</source>
        <translation>Publiceer</translation>
    </message>
</context>
<context>
    <name>UBKeyboardPalette</name>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
</context>
<context>
    <name>UBMainWindow</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>UBMessagesDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Sluiten</translation>
    </message>
</context>
<context>
    <name>UBNetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&gt;qt&gt;Gebrukersnaam en wachtwoord invoeren voor &quot;%1&quot; op %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Failed to log to Proxy</source>
        <translation>Proxy inloggen  mislukt</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors for this host?</source>
        <translation>SSL errors: %1 %2 Wilt u deze foutmeldingen negeren voor deze host?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
</context>
<context>
    <name>UBOpenSankoreImporterWidget</name>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Annuleren</translation>
    </message>
    <message>
        <source>Open-Sankore Documents Detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré documents are present on your computer. It is possible to import them to OpenBoard by pressing the “Proceed” button to launch the importer application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show this panel next time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can always access the OpenBoard Document Importer through the Preferences panel in the About tab. Warning, if you have already imported your Open-Sankore datas, you might loose your current OpenBoard documents.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proceed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPersistenceManager</name>
    <message>
        <source>(copy)</source>
        <translation>(copy)</translation>
    </message>
    <message>
        <source>Document Repository Loss</source>
        <translation>Documentopslag verloren</translation>
    </message>
    <message>
        <source>OpenBoard has lost access to the document repository &apos;%1&apos;. Unfortunately the application must shut down to avoid data corruption. Latest changes may be lost as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming pages (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retrieving all your documents (found : %1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPlatformUtils</name>
    <message>
        <source>English</source>
        <translation>Engels</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Duits</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Frans</translation>
    </message>
    <message>
        <source>Swiss French</source>
        <translation>Zwitsers Frans</translation>
    </message>
</context>
<context>
    <name>UBPodcastController</name>
    <message>
        <source>Failed to start encoder ...</source>
        <translation>Opstarten encoder mislukt...</translation>
    </message>
    <message>
        <source>No Podcast encoder available ...</source>
        <translation>Geen Podcast encoder beschikbaar...</translation>
    </message>
    <message>
        <source>Part %1</source>
        <translation>Deel%1</translation>
    </message>
    <message>
        <source>on your desktop ...</source>
        <translation>op uw bureaublad...</translation>
    </message>
    <message>
        <source>in folder %1</source>
        <translation>in map %1</translation>
    </message>
    <message>
        <source>Podcast created %1</source>
        <translation>Podcast gecreëerd %1</translation>
    </message>
    <message>
        <source>Podcast recording error (%1)</source>
        <translation>Podcast opname foutmelding (%1)</translation>
    </message>
    <message>
        <source>Default Audio Input</source>
        <translation>Standaard audio ingang</translation>
    </message>
    <message>
        <source>No Audio Recording</source>
        <translation>Geen audio-opname</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Gemiddeld</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Geheel</translation>
    </message>
    <message>
        <source>Publish to Intranet</source>
        <translation>Op internet publiceren</translation>
    </message>
    <message>
        <source>Publish to Youtube</source>
        <translation>Op Youtube publiceren</translation>
    </message>
    <message>
        <source>OpenBoard Cast</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBPreferencesController</name>
    <message>
        <source>version: </source>
        <translation>versie:</translation>
    </message>
    <message>
        <source>Marker is pressure sensitive</source>
        <translation>Markeerstift is druk gevoelig</translation>
    </message>
</context>
<context>
    <name>UBProxyLoginDlg</name>
    <message>
        <source>Proxy Login</source>
        <translation type="vanished">Proxy Login</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="vanished">Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="vanished">Wachtwoord:</translation>
    </message>
</context>
<context>
    <name>UBPublicationDlg</name>
    <message>
        <source>Publish document on the web</source>
        <translation type="vanished">Document op internet publiceren</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="vanished">Titel:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation type="vanished">Beschrijving:</translation>
    </message>
    <message>
        <source>Publish</source>
        <translation type="vanished">Publiceren</translation>
    </message>
</context>
<context>
    <name>UBSettings</name>
    <message>
        <source>My Movies</source>
        <translation>Mijn films</translation>
    </message>
</context>
<context>
    <name>UBStartupHintsPalette</name>
    <message>
        <source>Visible next time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTeacherBarWidget</name>
    <message>
        <source></source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UBThumbnailAdaptor</name>
    <message>
        <source>Generating preview thumbnails ...</source>
        <translation>Miniatuur bekijken...</translation>
    </message>
    <message>
        <source>%1 thumbnails generated ...</source>
        <translation>%1 miniaturen opgeladen...</translation>
    </message>
    <message>
        <source>Loading thumbnail (%1/%2)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBThumbnailTextItem</name>
    <message>
        <source>Page %0</source>
        <translation type="unfinished">Pagina %0</translation>
    </message>
</context>
<context>
    <name>UBToolsManager</name>
    <message>
        <source>Mask</source>
        <translation>Masker</translation>
    </message>
    <message>
        <source>Ruler</source>
        <translation>Liniaal</translation>
    </message>
    <message>
        <source>Compass</source>
        <translation>Kompas</translation>
    </message>
    <message>
        <source>Protractor</source>
        <translation>Gradenboog</translation>
    </message>
    <message>
        <source>Triangle</source>
        <translation>Driehoek</translation>
    </message>
    <message>
        <source>Magnifier</source>
        <translation>Vergrootglas</translation>
    </message>
    <message>
        <source>Cache</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Axes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBTrapFlashController</name>
    <message>
        <source>Whole page</source>
        <translation>Hele pagina</translation>
    </message>
    <message>
        <source>Web</source>
        <translation>Web</translation>
    </message>
</context>
<context>
    <name>UBUpdateDlg</name>
    <message>
        <source>Document updater</source>
        <translation>Document updater</translation>
    </message>
    <message>
        <source> files require an update.</source>
        <translation>Bestanden moeten geüpdate worden.</translation>
    </message>
    <message>
        <source>Backup path: </source>
        <translation>Backup pad:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Browse</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Update</translation>
    </message>
    <message>
        <source>Select a backup folder</source>
        <translation>Een backup map selecteren</translation>
    </message>
    <message>
        <source>Files update successful!
Please reboot the application to access the updated documents.</source>
        <translation>Mappen update gelukt! De applicatie opnieuw starten voor toegang tot de geüpdate documenten.</translation>
    </message>
    <message>
        <source>An error occured during the update. The files have not been affected.</source>
        <translation>Er is een fout opgetreden tijden de update.De mappen zijnniet beschadigd.</translation>
    </message>
    <message>
        <source>Files update results</source>
        <translation>Mappen update resultaten</translation>
    </message>
    <message>
        <source>Updating file </source>
        <translation>Bestand updaten</translation>
    </message>
    <message>
        <source>Please wait the import process will start soon...</source>
        <translation>Geduld, import kan ieder moment starten...</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UBWebPluginWidget</name>
    <message>
        <source>Loading...</source>
        <translation>Wordt geladen...</translation>
    </message>
</context>
<context>
    <name>UBWidgetUniboardAPI</name>
    <message>
        <source>%0 called (method=%1, status=%2)</source>
        <translation>%0 opgeroepen (methode=%1, status=%2)</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublisher</name>
    <message>
        <source>YouTube authentication failed.</source>
        <translation>YouTube identificatie mislukt.</translation>
    </message>
    <message>
        <source>Error while uploading video to YouTube (%1)</source>
        <translation>Fout opgetreden tijdens de upload van een You Tube video (%1)</translation>
    </message>
    <message>
        <source>Upload to YouTube in progress %1 %</source>
        <translation>Wordt naar You Tube geüpload %1%</translation>
    </message>
</context>
<context>
    <name>UBYouTubePublishingDialog</name>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Autos &amp; Vehicles</source>
        <translation>Auto&apos;s &amp; Voertuigen</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muziek</translation>
    </message>
    <message>
        <source>Pets &amp; Animals</source>
        <translation>Huisdieren &amp; Dieren</translation>
    </message>
    <message>
        <source>Sports</source>
        <translation>Sport</translation>
    </message>
    <message>
        <source>Travel &amp; Events</source>
        <translation>Reizen &amp; Evenementen</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Gaming</translation>
    </message>
    <message>
        <source>Comedy</source>
        <translation>Comedie</translation>
    </message>
    <message>
        <source>People &amp; Blogs</source>
        <translation>Mensen &amp; Blogs</translation>
    </message>
    <message>
        <source>News &amp; Politics</source>
        <translation>Nieuws &amp; Politiek</translation>
    </message>
    <message>
        <source>Entertainment</source>
        <translation>Entertainment</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>Onderwijs</translation>
    </message>
    <message>
        <source>Howto &amp; Style</source>
        <translation>Tips &amp; Stijl</translation>
    </message>
    <message>
        <source>Nonprofits &amp; Activism</source>
        <translation>Nonprofit organisaties &amp; Actievoering</translation>
    </message>
    <message>
        <source>Science &amp; Technology</source>
        <translation>Wetenschap &amp; Technologie</translation>
    </message>
</context>
<context>
    <name>UBZoomPalette</name>
    <message>
        <source>%1 x</source>
        <translation>%1 x</translation>
    </message>
</context>
<context>
    <name>WBClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Ruimen</translation>
    </message>
</context>
<context>
    <name>WBDownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Bestand opslaan</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download geannuleerd: %1</translation>
    </message>
    <message>
        <source>Error opening saved file: %1</source>
        <translation>Error opening geregistreerd bestand: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Error registratie:%1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Netwerk Error: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>seconden</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuten</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation>- %4 %5 te gaan</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 van %2 (%3/sec) %4</translation>
    </message>
    <message>
        <source>?</source>
        <comment>unknown file size</comment>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 van %2 - gestopt</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
</context>
<context>
    <name>WBDownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation>1 download</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <comment>always &gt;= 2</comment>
        <translation>%1 Downloads</translation>
    </message>
</context>
<context>
    <name>WBHistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
</context>
<context>
    <name>WBHistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Eerder deze dag</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation>%1 items</translation>
    </message>
</context>
<context>
    <name>WBSearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
<context>
    <name>WBTabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nieuw&amp;Tabblad</translation>
    </message>
    <message>
        <source>Clone Tab</source>
        <translation>Tabblad Klonen</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Tabblad Sluiten</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Sluiten&amp;Andere Tabbladen</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Tabblad weer opladen</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Alle Tabbladen weer opladen</translation>
    </message>
</context>
<context>
    <name>WBTabWidget</name>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Recent gesloten Tabbladen</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(geen titel)</translation>
    </message>
</context>
<context>
    <name>WBToolbarSearch</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Geen recente zoekopdrachten</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Recente zoekopdrachten</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Recente zoekopdrachten wissen</translation>
    </message>
</context>
<context>
    <name>WBWebPage</name>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Add to Current Document</source>
        <translation>Toevoegen aan Huidig Document</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Error loading page: %1</source>
        <translation>Error pagina opladen: %1</translation>
    </message>
    <message>
        <source>Download PDF Document: would you prefer to download the PDF file or add it to the current OpenBoard document?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WBWebView</name>
    <message>
        <source>Open in New Tab</source>
        <translation>In een Nieuw Tabblad openen</translation>
    </message>
</context>
<context>
    <name>XPDFRenderer</name>
    <message>
        <source>Processing...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>YouTubePublishingDialog</name>
    <message>
        <source>Publish Podcast to YouTube</source>
        <translation>Podcast via YouTube publiceren</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Trefwoorden</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <source>YouTube Username</source>
        <translation>YouTube Gebruikersnaam</translation>
    </message>
    <message>
        <source>YouTube Password</source>
        <translation>YouTube Wachtwoord</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;By clicking &apos;Upload,&apos; you certify that you own all rights to the content or that you are authorized by the owner to make the content publicly available on YouTube, and that it otherwise complies with the YouTube Terms of Service located at &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt;&quot;&gt;Door op  &apos;Upload,&apos;te klikken bevestigt u dat u over alle inhoudsrechten beschikt of dat u de toelating hebt gekregen van de eigenaar om de inhoud publiek te maken op YouTube, en dat u anderzijds akkoord gaat met de YouTube Terms of Service zoals beschreven op &lt;/span&gt;&lt;a href=&quot;http://www.youtube.com/t/terms&quot;&gt;&lt;span style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:10pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://www.youtube.com/t/terms&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>OpenBoard</source>
        <translation type="unfinished">Sankoré openen</translation>
    </message>
    <message>
        <source>Restore credentials on reboot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brushProperties</name>
    <message>
        <source>On Light Background</source>
        <translation>Op een Lichte Achtergrond</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation>Op een Donkere Achtergrond</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>lichtondoorlatendheid</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Lijndikte</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Dik</translation>
    </message>
    <message>
        <source>Fine</source>
        <translation>Dun</translation>
    </message>
    <message>
        <source>Pen is Pressure Sensitive</source>
        <translation>Pen is drukgevoelig</translation>
    </message>
    <message>
        <source>Show preview circle from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>capturePublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschrijving</translation>
    </message>
</context>
<context>
    <name>documentPublishingDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="obsolete">Dialoog</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Titel</translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="obsolete">E-mail</translation>
    </message>
    <message>
        <source>Author</source>
        <translation type="obsolete">Auteur</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="obsolete">Beschrijving</translation>
    </message>
</context>
<context>
    <name>documents</name>
    <message>
        <source>OpenBoard Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creation date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alphabetical order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>preferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Voorkeuren</translation>
    </message>
    <message>
        <source>version : …</source>
        <translation>versie : ....</translation>
    </message>
    <message>
        <source>Default Settings</source>
        <translation>Standaardinstellingen</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Display</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>Show Page with External Browser</source>
        <translation>Pagina weergeven met externe Browser</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Homepage:</translation>
    </message>
    <message>
        <source>Virtual Keyboard</source>
        <translation>Virtueel Toetsenbord</translation>
    </message>
    <message>
        <source>Keyboard button size:</source>
        <translation type="vanished">Formaat knoppen van toetsenbord:</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <source>Positioned at the Top (recommended for tablets)</source>
        <translation>Bovenaan geplaatst (aanbevolen voor tablets)</translation>
    </message>
    <message>
        <source>Positioned at the Bottom (recommended for white boards)</source>
        <translation>Onderaan geplaatst (aanbevolen voor schrijfborden)</translation>
    </message>
    <message>
        <source>Display Text Under Button</source>
        <translation>Tekst onder knop weergeven</translation>
    </message>
    <message>
        <source>Stylus Palette</source>
        <translation>Pen palet</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontaal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Verticaal</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markeerstift</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Software Update</source>
        <translation>Software update</translation>
    </message>
    <message>
        <source>Check software update at launch</source>
        <translation>Software update controleren bij opstarten</translation>
    </message>
    <message>
        <source>Licences</source>
        <translation>Licenties</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Show internal web page content on secondary screen or projector</source>
        <translation>Toon interne webpaginainhoud op tweede scherm of projector</translation>
    </message>
    <message>
        <source>Multi display</source>
        <translation>Multi display</translation>
    </message>
    <message>
        <source>Swap control display and view display</source>
        <translation>Wissel tussen control display en view display</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Manier</translation>
    </message>
    <message>
        <source>Mode to start in:</source>
        <translation>Manier van starten:</translation>
    </message>
    <message>
        <source>Board</source>
        <translation>Bord</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Bureaublad</translation>
    </message>
    <message>
        <source>Proxy User:</source>
        <translation>Proxy Gebruiker:</translation>
    </message>
    <message>
        <source>Pass:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Credits</source>
        <translation>Credits</translation>
    </message>
    <message>
        <source>On Dark Background</source>
        <translation type="unfinished">Op een Donkere Achtergrond</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished">lichtondoorlatendheid</translation>
    </message>
    <message>
        <source>On Light Background</source>
        <translation type="unfinished">Op een Lichte Achtergrond</translation>
    </message>
    <message>
        <source>Swap first and second view displays</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Built-in virtual keyboard button size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use system keyboard (recommended)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open-Sankoré Importer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check if Open-Sankoré data could be imported at launch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display date column on alphabetical sort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Empty trash for documents older than</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Improve zoom execution time (can slightly affect rendering quality)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>trapFlashDialog</name>
    <message>
        <source>Trap flash</source>
        <translation>Trap flash</translation>
    </message>
    <message>
        <source>Select a flash to trap</source>
        <translation type="vanished">Te vangen licht selecteren</translation>
    </message>
    <message>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <source>Application name</source>
        <translation>Applicatie naam</translation>
    </message>
    <message>
        <source>Create Application</source>
        <translation>Applicatie maken</translation>
    </message>
    <message>
        <source>Select a content to capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
